==> common-1.0.14-sources.jar: com/microsoft/identity/common/internal/eststelemetry/IRequestTelemetryCache.java <==
// Copyright (c) Microsoft Corporation.
// All rights reserved.
//
// This code is licensed under the MIT License.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files(the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions :
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
package com.microsoft.identity.common.internal.eststelemetry;

/**
 * This is a "cache of one" i.e. there will always be only one RequestTelemetry object saved
 * saved in the cache at any given time
 */
public interface IRequestTelemetryCache {

    /**
     * Save telemetry associated to the {@link RequestTelemetry} object to the cache
     *
     * @param requestTelemetry
     */
    void saveRequestTelemetryToCache(final RequestTelemetry requestTelemetry);

    /**
     * Get the telemetry from the cache
     *
     * @return a {@link RequestTelemetry} object
     */
    RequestTelemetry getRequestTelemetryFromCache();


    /**
     * Clear the contents of the cache.
     */
    void clearAll();


}

==> common-3.0.2-sources.jar: com/microsoft/identity/common/internal/eststelemetry/IRequestTelemetryCache.java <==
// Copyright (c) Microsoft Corporation.
// All rights reserved.
//
// This code is licensed under the MIT License.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files(the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions :
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
package com.microsoft.identity.common.internal.eststelemetry;

/**
 * This is a "cache of one" i.e. there will always be only one RequestTelemetry object saved
 * in the cache at any given time
 */
public interface IRequestTelemetryCache {

    /**
     * Save telemetry associated to the {@link RequestTelemetry} object to the cache
     *
     * @param requestTelemetry
     */
    void saveRequestTelemetryToCache(final RequestTelemetry requestTelemetry);

    /**
     * Get the telemetry object from the cache
     *
     * @return a {@link RequestTelemetry} object
     */
    RequestTelemetry getRequestTelemetryFromCache();
}
